refresh abstract method
It either updates the data found at key with value or, if there is no
previous data at key, creates a new cache line at key with value.
Note: value must be json encodable.
Implementation
Future<void> refresh(String key, Map<String, dynamic> value);